@@ -39,7 +39,7 @@ __copyright__ = """
 2019-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.8.3"
+__version__ = "0.9.0"
 modname = "domdf_python_tools"
 pypi_name = "domdf_python_tools"
 import_name = "domdf_python_tools"
@@ -51,7 +51,7 @@ github_username = "domdfcoding"
 web = github_url = "https://github.com/domdfcoding/domdf_python_tools"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {'dates': ['pytz>=2019.1'], 'all': ['pytz>=2019.1']}
+extras_require = {'dates': ['pytz>=2019.1'], 'testing': ['pytest>=6.0.0'], 'all': ['pytest>=6.0.0', 'pytz>=2019.1']}
 
 
 
