@@ -24,6 +24,7 @@ NamedTuple-like class to represent a version number.
 #
 
 # stdlib
+import re
 from typing import Generator, Sequence, Tuple, Union
 
 __all__ = ["Version"]
@@ -176,22 +177,27 @@ class Version(Tuple[int, int, int]):
 
 		:param version_string: The version number.
 
-		:return: The created Version
+		:return: The created :class:`~domdf_python_tools.versions.Version`.
 		"""
 
 		return cls(*_iter_string(version_string))
 
 	@classmethod
-	def from_tuple(cls, version_tuple: Tuple[Union[str, int], Union[str, int], Union[str, int]]) -> "Version":
+	def from_tuple(cls, version_tuple: Tuple[Union[str, int], ...]) -> "Version":
 		"""
 		Create a :class:`~.Version` from a :class:`tuple`.
 
 		:param version_tuple: The version number.
 
-		:return: The created Version
+		:return: The created :class:`~domdf_python_tools.versions.Version`.
+
+		.. versionchanged:: 0.9.0
+
+			Tuples with more than three elements are truncated.
+			Previously a :exc:`TypeError` was raised.
 		"""
 
-		return cls(*(int(x) for x in version_tuple))
+		return cls(*(int(x) for x in version_tuple[:3]))
 
 	@classmethod
 	def from_float(cls, version_float: float) -> "Version":
@@ -200,7 +206,7 @@ class Version(Tuple[int, int, int]):
 
 		:param version_float: The version number.
 
-		:return: The created Version
+		:return: The created :class:`~domdf_python_tools.versions.Version`.
 		"""
 
 		return cls.from_str(str(version_float))
@@ -215,7 +221,7 @@ def _iter_string(version_string: str) -> Generator[int, None, None]:
 	:return: Iterable elements of the version.
 	"""
 
-	return (int(x) for x in version_string.split("."))
+	return (int(x) for x in re.split("[.,]", version_string))
 
 
 def _iter_float(version_float: float) -> Generator[int, None, None]:
